#!/usr/bin/env python3

from typing import List
import sys
import os

from PyQt5 import uic
from PyQt5 import QtCore
from PyQt5.QtWidgets import QApplication, QMainWindow



__all__ = []


default_score_threshold = 0.35


class MainWindow(QMainWindow):
    def __init__(
            self,
            score_threshold: float = default_score_threshold,
            parent=None
    ) -> None:
        super().__init__(parent=parent)

        uic.loadUi(
            os.path.join(
                "tests", "audio", "mtest_audiogenerator", "mainwindow.ui"
            ),
            self
        )

        self.score_value_spinbox.valueChanged.connect(
            self._on_score_spinbox_value_changed)
        self.score_value_slider.valueChanged.connect(
            self._on_score_slider_value_changed)

    @QtCore.pyqtSlot(float)
    def _on_score_spinbox_value_changed(self, value: float) -> None:
        self.score_value_slider.setValue(int(value * 100.0))
        self._audio_generator.set_score(value)

    @QtCore.pyqtSlot(int)
    def _on_score_slider_value_changed(self, value: int) -> None:
        self.score_value_spinbox.setValue(value / 100.0)


def main(args: List[str]) -> int:
    app = QApplication(args)

    main_window = MainWindow()
    main_window.show()

    return app.start_app()


if __name__ == "__main__":
    sys.exit(main(sys.argv))
